% diox_basis     Truncated Hund's case (b) basis for dioxygen
%
%    [J,M,N] = diox_basis(Nmax)
%
%    Returns a truncated Hund's case (b) basis for dioxygen.
%    Vectors J, N and M contain the quantum numbers of all
%    states |J,N,M> for N odd and N <= Nmax. The quantum
%    numbers are
%
%       N = 1, 3, 5, ..., Nmax
%       J = N-1, N, N+1
%       M = -J, ..., J
%       ( and S = 1 for all states)

function [J,N,M] = diox_basis(Nmax)

iBasis = 1;

for iN = 1:2:Nmax       % N = 1,3,5,...,Nmax
  for iJ = iN-1:iN+1    % J = N-1,N,N+1
    for iM = -iJ:iJ     % M = -J,...,J

      N(iBasis) = iN;
      J(iBasis) = iJ;
      M(iBasis) = iM;

      iBasis = iBasis + 1;

    end
  end
end
