function varargout = diox_eig(H,M);

% Provide demo parameters
%---------------------------------------------------------------
if (nargin==0)
  Nmax = 5;
  Field = 1;
  [J,N,M] = diox_basis(Nmax);
  [H0,H1] = diox_hamiltonian(Nmax);
  H = H0 + Field*H1;
end

% Sort basis according to M values
%---------------------------------------------------------------
[M,idx0] = sort(M);
[dum,idx1] = sort(idx0);

Hs = H(idx0,idx0);  % transform Hamiltonian from unsorted to sorted basis


% Pick out submatrix for each M and diagonalize separately
%---------------------------------------------------------------
Mvalues = min(M):max(M);
for im=1:numel(Mvalues)
  idx = M==Mvalues(im);
  [VM,EM] = eig(Hs(idx,idx));
  V{im} = VM;
  E{im} = diag(EM);
end

% Combine eigenvalues and eigenvectors
%---------------------------------------------------------------
V = blkdiag(V{:});
E = cat(1,E{:});

% Sort eigenvalues and vectors
[E,idx] = sort(E);
% and transform from sorted basis back to unsorted basis
V = V(idx1,idx);

if nargout==1
  varargout = {E};
elseif nargout==2
  varargout = {V,E};
end

return
