% diox_hamiltonian   Constructs the Hamiltonian matrix for dioxygen
%
%    [H0,H1] = diox_hamiltonian(Nmax)
%
%    Nmax   maximum quantum number N
%
%    H0     field-free Hamiltonian, in MHz
%    H1     field-dependent Hamiltonian, in MHz/T
%           (still to be multiplied by the field strength!)

function [H0,H1,Sx] = diox_hamiltonian(Nmax)

% Parameters of the ground state of dioxygen
Pars = diox_params;

% Truncated basis |J N M> for odd N<=Pars.Nmax
[J,N,m] = diox_basis(Nmax);

% Matrix representation of all operators needed
[N2,NS,SzS2,Sz,Sx] = diox_matrices(J,N,m);

% Physical constants (CODATA 2002 values)
muB =  9.27400949e-24;    % Bohr magneton [J/T]
h = 6.6260693e-34;        % Planck constant [J s]

% Field-free Hamiltonian [MHz]
H0 = Pars.B*N2 + 2/3*Pars.lambda*SzS2 + Pars.mu*NS;
% Zeeman Hamiltonian [MHz/T]
H1 = muB/h/1e6*(Pars.gS-Pars.gL)*Sz;
