% diox_params    Molecular parameters of ground-state dioxygen
%
%    Pars = diox_params
%
%    Provides all the constants necessary to construct the
%    Hamiltonian of dioxygen, like rotational, centrifugal
%    distortion, spin-rotation constant etc.
%
%    Pars.B       rotational constant, in MHz
%    Pars.D       centrifugal distortion constant, in MHz
%    Pars.lambda  spin-spin constant, in MHz
%    Pars.mu      spin-rotation constant, in MHz
%
%    Pars.gS      electron spin g factor
%    Pars.gL      electron orbital g factor
%    Pars.gR      rotational g factor

function Pars = diox_params

% Parameters of the $^3\Sigma$ ground state of dioxygen

% Taken from Tomuta, Phys.Rev.A 12, 974-979 (1975)
Pars.B = +43100.5;       % rotational constant, MHz
Pars.D = +0.145;         % centrifugal distortion constant, MHz
Pars.lambda = +59501.3;  % spin-spin interaction, MHz
Pars.mu = -252.6;        % spin-rotation constant MHz

% Taken from Gerber, Helv.Phys.Acta 45, 655-682(1972)
Pars.gS = +2.002113;     % electron spin g factor
Pars.gL = -0.002816;     % electron orbital g factor
Pars.gR = -0.000128;     % rotational g factor
