% Filename containing the experimental spectrum in ASCII format
% (first column: magnetic field in tesla, second column: spectral intensity)
FileName = 'diox_spec.dat';
mwFreq = 9.529533; % GHz

% Maximum rotational quantum number for the simulation (odd values up
% to 29 are reasonable).
Nmax = 17;

% Loading the experimental spectrum
%==========================================
[idx,B,spc] = textread(FileName,'%d %f %f','headerlines',2);
B = B/1e4; % convert Gauss to Tesla
spc = spc/max(spc);      % normalize


% Simulation of the spectrum
%==========================================
FieldRange = [min(B) max(B)];
[B1,spcs] = diox_sim(FieldRange,Nmax,mwFreq);
spc1 = sum(spcs,1);
spc1 = spc1/max(spc1(:));   % normalize


% Plotting
%==========================================
plot(B,spc,'k',B1,spc1,'r');
axis tight
xlabel('magnetic field [T]');
ylabel('intensity [a.u.]');
